@@ -15,7 +15,7 @@ checkInstalledVersion()
   # version of DART being installed has to be greater than the current DART version
   if [ -f ${DARTMANIFEST} ]; then
       DARTPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${DARTMANIFEST})
-      DARTCURRVERSION=4.10.05095
+      DARTCURRVERSION=4.10.07061
 
       if [ $(version $DARTCURRVERSION) -le $(version $DARTPREVVERSION) ]; then
         failed=true
@@ -50,7 +50,7 @@ UNINSTALL="${VPNBIN}/dart_uninstall.sh"
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.10.05095-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.07061-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
 
 DARTMANIFEST="${INSTPREFIX}/ACManifestDART.xml"
 
@@ -269,6 +269,13 @@ else
     echo "${NEWTEMP}/NetworkVisibility.xml does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/DART.xml" ]; then
+    echo "Installing "${NEWTEMP}/DART.xml >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 444 ${NEWTEMP}/DART.xml ${CONFIGDIR} || exit 1
+else
+    echo "${NEWTEMP}/DART.xml does not exist. It will not be installed."
+fi
+
 if [ -f "${NEWTEMP}/ConfigXMLSchema.xsd" ]; then
     echo "Installing "${NEWTEMP}/ConfigXMLSchema.xsd >> /tmp/${LOGFNAME}
     ${INSTALL} -o root -m 444 ${NEWTEMP}/ConfigXMLSchema.xsd ${CONFIGDIR} || exit 1
