@@ -2,7 +2,7 @@
 #
 
 BASH_BASE_SIZE=0x00001af8
-CISCO_AC_TIMESTAMP=0x00000000624c79d2
+CISCO_AC_TIMESTAMP=0x00000000644c35c2
 CISCO_AC_OBJNAME=iseposture_install.sh                                           
 # BASH_BASE_SIZE=0x00000000 is required for signing
 # the comment is after or else the code signing tool will find the comment
@@ -22,7 +22,7 @@ ISEPLUGINFILES="libacisectrl.so libaciseshim.so"
 ISEPOSTUREMANIFEST="ACManifestISEPosture.xml"
 VPNMANIFEST="${ANYCONNECT_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`date "+anyconnect-linux64-4.10.05095-iseposture-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.07061-iseposture-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect ISE Posture Module"
 CURRENTDIR=`dirname $0 2> /dev/null`
 
@@ -233,9 +233,9 @@ q`-euX0U#0E뢯˂1-Q!m0
 	*H
   >
 Z$",|%)v]-:0a~`=į* U7ђuQnZ^$N?qcK_Dy6FN\Q$$'*)(:q(<.%Gzhh\ \qh@@Dd%B26$/r~IEYtdkfCڳ
- Ι1c=OƓIbnS.hlD2fdQ  ch(L_(g5~A{H}D2YcpIcxǬ,DS?_Ja]o[
-E>4'w k'jʯ[|1!!dZ٫bx{ 
-+Xt8Ha1BB-A$pqa?82jWPE$EͤV!r5Q51{ꐌpo(fF>
-~	6.d)~h2h)6I%	4*"tNjz_&ƪ  ;3a/xfUxU:B:d
-ts\VZes=P`k.)u](kO*eє&lPNfR=|xln? .YVUA%3E:hk玀bf
-2mbamG{g8tS:M*/%%5AOX\#M	k2F^W\Qb	#b	hJސ5ݦs|C719I	B8
\ No newline at end of file
+ Ι1c=OƓIbnS.hlD2fdQ  I, 3Fg}DS0 E8e>\Q"p@нSaٛcSutz cEEG8,VU0lmo_smC!4oD@ݷ3:R~f
+	<Mt(,zӉ 
+5 &<34OgMXRk8ž}O)O#p=Xn5EsKGh+&Ũ{:;y'#U;l
+I{
+2  `Ƣ
+܊%	Zn!pj[l͒~GTdKj|,gQ/>}K/-uQHbs/O+6Wsc52,5aBn%fqQY-Ƽ딟U|!eNkjp\[zXÆf@	}z#厜ۿZ"Xs!ǌb!)R%2IRN+"ntmj)k4eῖ"
\ No newline at end of file
