@@ -9,7 +9,7 @@ checkInstalledHSVersion()
   # version of HS being installed has to be greater than the current HS version
   if [ -f ${HSMANIFEST} ]; then
       HSPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${HSMANIFEST})
-      HSCURRVERSION=4.10.04071
+      HSCURRVERSION=4.10.07061
 
       if [ $(version $HSCURRVERSION) -le $(version $HSPREVVERSION) ]; then
         failed=true
@@ -33,6 +33,9 @@ exitInstallation()
   echo "Exiting now."
   echo "Exiting now." >> /tmp/${LOGFNAME}
 
+  if [ ! -f "${LOGDIR}" ] ; then
+    mkdir -p ${LOGDIR}
+  fi
   # move the logfile out of the tmp directory
   mv /tmp/${LOGFNAME} ${LOGDIR}
   exit $1
@@ -83,11 +86,13 @@ SYSVSTARTNUM="85"
 SYSVSTOP="K25"
 SYSVSTOPNUM="25"
 SYSVLEVELS="2 3 4 5"
+CURRENTDIR=`dirname $0 2> /dev/null`
+VPNMANIFEST="${ANYCONNECT_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`/bin/date "+posture-4.10.04071-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`/usr/bin/date "+posture-4.10.04071-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`date "+posture-4.10.04071-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=posture-4.10.04071-install.log
+LOGFNAME=`/bin/date "+posture-4.10.07061-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`/usr/bin/date "+posture-4.10.07061-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`date "+posture-4.10.07061-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=posture-4.10.07061-install.log
 
 DIR=`dirname $0 2> /dev/null` || 
   DIR=`/usr/bin/dirname $0 2> /dev/null` || 
@@ -163,7 +168,7 @@ do
 done
 
 echo "Installing Cisco AnyConnect Posture Module..."
-echo "Installing Cisco AnyConnect Posture Module v4.10.04071..." > /tmp/${LOGFNAME}
+echo "Installing Cisco AnyConnect Posture Module v4.10.07061..." > /tmp/${LOGFNAME}
 echo `whoami` "invoked $0 from " `pwd` " at " `date` >> /tmp/${LOGFNAME}
 echo ""
 
@@ -173,6 +178,30 @@ if [ "x${ID}" != "x0" ]; then
   exitInstallation 1
 fi
 
+# Posture requires VPN to be installed. We check the presence of the vpn manifest file to check if it is installed.
+if [ ! -f ${VPNMANIFEST} ]; then
+    echo "AnyConnect VPN should be installed before Posture installation. Install AnyConnect VPN to proceed."
+    echo "AnyConnect VPN should be installed before Posture installation. Install AnyConnect VPN to proceed." >> /tmp/${LOGFNAME}
+    exitInstallation 1
+fi
+
+postureVersionMatchesVPN=false
+# version of posture being installed has to be same as installed VPN version
+if [ -f "${CURRENTDIR}/${POSTUREMANIFEST}" ] && [ -f ${VPNMANIFEST} ]; then
+    VPNVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
+    POSTURECURRVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${CURRENTDIR}/${POSTUREMANIFEST})
+
+    if [ $(version $VPNVERSION) -eq $(version $POSTURECURRVERSION) ]; then
+     postureVersionMatchesVPN=true
+    fi
+fi
+
+if [ "$postureVersionMatchesVPN" = false ]; then
+    echo "Please use posture installer from Anyconnect package with version ${VPNVERSION} for the installation"
+    echo "Please use posture installer from Anyconnect package with version ${VPNVERSION} for the installation" >> /tmp/${LOGFNAME}
+    exitInstallation 1
+fi
+
 
 if [ "x${ARG_NO_LICENSE}" = "x1" ]; then
 
